@@ -2,16 +2,16 @@ use std::sync::Arc;
 use std::sync::atomic::{AtomicBool, Ordering};
 use std::time::Duration;
 
-use log::info;
+/*use log::info;
 use async_std::{io, future};
 use async_std::net::UdpSocket;
 use mediasoup::producer::Producer;
-use mediasoup::rtp_parameters::MediaKind;
+use mediasoup::rtp_parameters::MediaKind;*/
 
-use crate::rtc::routers::{DataSource, HyperspeedRouter};
+use crate::rtc::routers::{HyperspeedRouter};
 
 impl HyperspeedRouter {
-    pub async fn launch_ingest(&self, addr: String, should_stop: Arc<AtomicBool>) -> Result<(), io::Error> {
+    /*pub async fn launch_ingest(&self, addr: String, should_stop: Arc<AtomicBool>) -> Result<(), io::Error> {
         match &self.source {
             DataSource::Ftl(data) => {
                 let video_producer = self.producers
@@ -48,20 +48,20 @@ impl HyperspeedRouter {
                         // ! FIXME: we should validate _src is the same as the address of the FTL peer
 
                         // Fast packet validation
-                        if amt > 2 {
+                        /*if amt > 2 {
                             let payload_type = buf[1] & 0b1111111;
                             if video_payload_type == payload_type {
                                 if let Some(video) = video_producer {
-                                    video.send(bytes::Bytes::copy_from_slice(&buf[0..amt])).await.unwrap();
+                                    video.send(buf[1..amt].to_vec()).unwrap();
                                 }
                             } else if audio_payload_type == payload_type {
                                 if let Some(audio) = audio_producer {
-                                    audio.send(bytes::Bytes::copy_from_slice(&buf[0..amt])).await.unwrap();
+                                    audio.send(buf[1..amt].to_vec()).unwrap();
                                 }
                             }
-                        }
+                        }*/
 
-                        /*use rtp::packet::Packet;
+                        use rtp::packet::Packet;
                         use webrtc_util::marshal::{Marshal, Unmarshal};
                 
                         if let Ok(packet) = Packet::unmarshal(&mut &buf[..amt]) {
@@ -70,17 +70,27 @@ impl HyperspeedRouter {
 
                             if video_payload_type == packet.header.payload_type {
                                 if let Some(video) = video_producer {
-                                    video.send(packet.marshal().unwrap()).await.unwrap();
+                                    video.send(packet.marshal().unwrap().to_vec()).unwrap();
                                 }
                             } else if audio_payload_type == packet.header.payload_type {
                                 if let Some(audio) = audio_producer {
-                                    audio.send(packet.marshal().unwrap()).await.unwrap();
+                                    audio.send(packet.marshal().unwrap().to_vec()).unwrap();
                                 }
                             }
-                        }*/
+                        }
                     }
                 }
             }
         }
+    }*/
+
+    pub async fn launch_ingest(&self, should_stop: Arc<AtomicBool>) {
+        loop {
+            if should_stop.swap(false, Ordering::Relaxed) {
+                break;
+            }
+
+            async_std::task::sleep(Duration::from_millis(100)).await;
+        }
     }
 }
